==> apache-doris-2.1.3-rc09-src.tar.gz: apache-doris-2.1.3-rc09-src/fe/fe-core/src/main/java/org/apache/doris/nereids/rules/implementation/LogicalOlapTableSinkToPhysicalOlapTableSink.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.apache.doris.nereids.rules.implementation;

import org.apache.doris.nereids.rules.Rule;
import org.apache.doris.nereids.rules.RuleType;
import org.apache.doris.nereids.trees.plans.Plan;
import org.apache.doris.nereids.trees.plans.logical.LogicalOlapTableSink;
import org.apache.doris.nereids.trees.plans.physical.PhysicalOlapTableSink;

import java.util.Optional;

/**
 * Implementation rule that convert logical OlapTableSink to physical OlapTableSink.
 */
public class LogicalOlapTableSinkToPhysicalOlapTableSink extends OneImplementationRuleFactory {
    @Override
    public Rule build() {
        return logicalOlapTableSink().thenApply(ctx -> {
            LogicalOlapTableSink<? extends Plan> sink = ctx.root;
            return new PhysicalOlapTableSink<>(
                    sink.getDatabase(),
                    sink.getTargetTable(),
                    sink.getCols(),
                    sink.getPartitionIds(),
                    sink.getOutputExprs(),
                    ctx.connectContext.getSessionVariable().isEnableSingleReplicaInsert(),
                    sink.isPartialUpdate(),
                    sink.getDmlCommandType(),
                    Optional.empty(),
                    sink.getLogicalProperties(),
                    sink.child());
        }).toRule(RuleType.LOGICAL_OLAP_TABLE_SINK_TO_PHYSICAL_OLAP_TABLE_SINK_RULE);
    }
}

==> apache-doris-2.1.11-rc01-src.tar.gz: apache-doris-2.1.11-rc01-src/fe/fe-core/src/main/java/org/apache/doris/nereids/rules/implementation/LogicalOlapTableSinkToPhysicalOlapTableSink.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.apache.doris.nereids.rules.implementation;

import org.apache.doris.nereids.rules.Rule;
import org.apache.doris.nereids.rules.RuleType;
import org.apache.doris.nereids.trees.plans.Plan;
import org.apache.doris.nereids.trees.plans.logical.LogicalOlapTableSink;
import org.apache.doris.nereids.trees.plans.physical.PhysicalOlapTableSink;

import java.util.Optional;

/**
 * Implementation rule that convert logical OlapTableSink to physical OlapTableSink.
 */
public class LogicalOlapTableSinkToPhysicalOlapTableSink extends OneImplementationRuleFactory {
    @Override
    public Rule build() {
        return logicalOlapTableSink().thenApply(ctx -> {
            LogicalOlapTableSink<? extends Plan> sink = ctx.root;
            return new PhysicalOlapTableSink<>(
                    sink.getDatabase(),
                    sink.getTargetTable(),
                    sink.getCols(),
                    sink.getPartitionIds(),
                    sink.getOutputExprs(),
                    ctx.connectContext.getSessionVariable().isEnableMemtableOnSinkNode() ? false
                            : ctx.connectContext.getSessionVariable().isEnableSingleReplicaInsert(),
                    sink.isPartialUpdate(),
                    sink.getDmlCommandType(),
                    Optional.empty(),
                    sink.getLogicalProperties(),
                    sink.child());
        }).toRule(RuleType.LOGICAL_OLAP_TABLE_SINK_TO_PHYSICAL_OLAP_TABLE_SINK_RULE);
    }
}
